@@ -1379,7 +1379,7 @@ gfi_write_fontmap (FILE * f)
 		goodfont_list = g_slist_remove (goodfont_list, goodfont_list->data);
 	}
 
-	xmlDocDump (f, doc);
+	xmlDocFormatDump (f, doc, 1);
 }
 
 static void
