@@ -27,6 +27,7 @@
 
 #define __GNOME_PRINT_META_C__
 
+#include "config.h"
 #include <math.h>
 #include <string.h>
 #include <sys/types.h>
@@ -39,7 +40,6 @@
 #include <libgnomeprint/gnome-glyphlist-private.h>
 #include <libgnomeprint/gnome-print-private.h>
 #include <libgnomeprint/gnome-print-meta.h>
-#include <gnome-print-private.h>
 #include "gp-gc-private.h"
 
 #define noVERBOSE
@@ -47,8 +47,9 @@
 struct _GnomePrintMeta {
 	GnomePrintContext pc;
 
+#ifdef GNOME_PRINT_ENABLE_PAGE_CALLBACKS	
 	guint flat : 1; /* Whether to flatten callbacks */
-
+#endif
 	guchar *buf;
 
 	gint b_length;
@@ -87,7 +88,9 @@ typedef enum {
 	GNOME_META_COLOR,
 	GNOME_META_LINE,
 	GNOME_META_DASH,
+#ifdef GNOME_PRINT_ENABLE_PAGE_CALLBACKS 
 	GNOME_META_CALLBACK
+#endif
 } GnomeMetaType;
 
 typedef enum {
@@ -112,8 +115,10 @@ static int meta_fill (GnomePrintContext *pc, const ArtBpath *bpath, ArtWindRule
 static int meta_stroke (GnomePrintContext *pc, const ArtBpath *bpath);
 static int meta_image (GnomePrintContext *pc, const gdouble *affine, const guchar *px, gint w, gint h, gint rowstride, gint ch);
 static int meta_glyphlist (GnomePrintContext *pc, const gdouble *affine, GnomeGlyphList *gl);
+#ifdef GNOME_PRINT_ENABLE_PAGE_CALLBACKS
 static gint gnome_print_meta_callback (GnomePrintContext *ctx, const guchar *name,
 				       gpointer pagedata, gpointer docdata, GClosure *closure);
+#endif
 static int meta_close (GnomePrintContext *pc);
 
 static void meta_color (GnomePrintContext *pc);
@@ -182,7 +187,9 @@ gnome_print_meta_class_init (GnomePrintMetaClass *klass)
 	pc_class->image = meta_image;
 	pc_class->glyphlist = meta_glyphlist;
 
+#ifdef GNOME_PRINT_ENABLE_PAGE_CALLBACKS
 	pc_class->page = gnome_print_meta_callback;
+#endif	
 
 	pc_class->close = meta_close;
 }
@@ -190,7 +197,9 @@ gnome_print_meta_class_init (GnomePrintMetaClass *klass)
 static void
 gnome_print_meta_init (GnomePrintMeta *meta)
 {
+#ifdef GNOME_PRINT_ENABLE_PAGE_CALLBACKS	
 	meta->flat = TRUE;
+#endif	
 
 	meta->buf = g_new (guchar, BLOCKSIZE);
 	meta->b_length = 0;
@@ -234,7 +243,8 @@ meta_beginpage (GnomePrintContext *ctx, const guchar *name)
 
 	/* Encode beginpage */
 	gpm_encode_int (ctx, GNOME_META_BEGINPAGE);
-	if (!name) name = "";
+	if (!name)
+		name = "";
 	gpm_encode_string (ctx, name);
 
 	return GNOME_PRINT_OK;
@@ -346,8 +356,9 @@ meta_glyphlist (GnomePrintContext *pc, const gdouble *affine, GnomeGlyphList *gl
 	gint i;
 
 	gpm_encode_int (pc, GNOME_META_GLYPHLIST);
-	for (i = 0; i < 6; i++) gpm_encode_double (pc, affine[i]);
-
+	for (i = 0; i < 6; i++) {
+		gpm_encode_double (pc, affine[i]);
+	}
 	gpm_encode_int (pc, gl->g_length);
 	for (i = 0; i < gl->g_length; i++) {
 		gpm_encode_int (pc, gl->glyphs[i]);
@@ -383,6 +394,7 @@ meta_glyphlist (GnomePrintContext *pc, const gdouble *affine, GnomeGlyphList *gl
 	return GNOME_PRINT_OK;
 }
 
+#ifdef GNOME_PRINT_ENABLE_PAGE_CALLBACKS
 static gint gnome_print_meta_callback (GnomePrintContext *ctx,
 				       const guchar *name,
 				       gpointer pagedata,
@@ -418,6 +430,7 @@ static gint gnome_print_meta_callback (GnomePrintContext *ctx,
 
 	return GNOME_PRINT_OK;
 }
+#endif
 
 static gint
 meta_close (GnomePrintContext *ctx)
@@ -505,7 +518,9 @@ gnome_print_meta_new_local (void)
 
 	meta = g_object_new (GNOME_TYPE_PRINT_META, NULL);
 
+#ifdef GNOME_PRINT_ENABLE_PAGE_CALLBACKS	
 	meta->flat = FALSE;
+#endif	
 
 	return (GnomePrintContext *) meta;
 }
@@ -603,6 +618,7 @@ gpm_decode_string (const guchar *data, guchar **dest)
 	return data + len;
 }
 
+#ifdef GNOME_PRINT_ENABLE_PAGE_CALLBACKS
 static const guchar *
 decode_block (const char *data, void *out, int len)
 {
@@ -611,12 +627,12 @@ decode_block (const char *data, void *out, int len)
 }
 
 /* Unportable */
-
 static const guchar *
 gpm_decode_pointer (const guchar *data, gpointer *ptr)
 {
 	return decode_block (data, ptr, sizeof (*ptr));
 }
+#endif
 
 static gint
 gpm_render (GnomePrintContext *dest, const guchar *data, gint pos, gint len, gboolean pageops)
@@ -640,7 +656,8 @@ gpm_render (GnomePrintContext *dest, const guchar *data, gint pos, gint len, gbo
 		switch ((GnomeMetaType) opcode) {
 		case GNOME_META_BEGINPAGE:
 			data = gpm_decode_string (data, &cval);
-			if (pageops) gnome_print_beginpage (dest, cval);
+			if (pageops)
+				gnome_print_beginpage (dest, cval);
 			g_free (cval);
 			break;
 		case GNOME_META_SHOWPAGE:
@@ -743,7 +760,8 @@ gpm_render (GnomePrintContext *dest, const guchar *data, gint pos, gint len, gbo
 						data = decode_double (data, &dval);
 						data = gpm_decode_string (data, &name);
 						font = gnome_font_find (name, dval);
-						if (font == NULL) g_print ("Cannot find font: %s\n", name);
+						if (font == NULL)
+							g_warning ("Cannot find font: %s\n", name);
 						g_free (name);
 						gl->rules[i].value.font = font;
 						break;
@@ -759,6 +777,7 @@ gpm_render (GnomePrintContext *dest, const guchar *data, gint pos, gint len, gbo
 			gnome_glyphlist_unref (gl);
 			break;
 		}
+#ifdef GNOME_PRINT_ENABLE_PAGE_CALLBACKS 
 		case GNOME_META_CALLBACK: {
 			GnomePrintPageCallback callback;
 			gpointer pagedata, docdata;
@@ -770,6 +789,7 @@ gpm_render (GnomePrintContext *dest, const guchar *data, gint pos, gint len, gbo
 			gnome_print_page_callback (dest, callback, name, pagedata, docdata);
 			g_free (name);
 		}
+#endif
 		break;
 		case GNOME_META_COLOR: {
 			gdouble r, g, b, a;
@@ -859,7 +879,8 @@ gnome_print_meta_render_data_page (GnomePrintContext *ctx, const guchar *data, g
 		g_return_val_if_fail (!strncmp (data + pos, PAGE_SIGNATURE, PAGE_SIGNATURE_SIZE), GNOME_PRINT_ERROR_UNKNOWN);
 		gpm_decode_int_header (data + pos + PAGE_SIGNATURE_SIZE, &len);
 		pos += PAGE_HEADER_SIZE;
-		if (len == 0) len = length - pos;
+		if (len == 0)
+			len = length - pos;
 		if (pagenum == page) {
 			return gpm_render (ctx, data, pos, len, pageops);
 		}
