@@ -28,6 +28,7 @@
 
 #define __GNOME_PRINT_TRANSPORT_C__
 
+#include "config.h"
 #include <string.h>
 #include <locale.h>
 #include <gmodule.h>
@@ -179,7 +180,7 @@ gint
 gnome_print_transport_printf (GnomePrintTransport *transport, const char *format, ...)
 {
 	va_list arguments;
-	const char *loc;
+	char *loc;
 	gchar *buf;
 	gint ret;
 
@@ -207,56 +208,77 @@ gnome_print_transport_printf (GnomePrintTransport *transport, const char *format
 	return ret;
 }
 
-GnomePrintTransport *
-gnome_print_transport_new (GnomePrintConfig *config)
+
+static GnomePrintTransport *
+gnome_print_transport_new_from_module_name (const gchar *module_name, GnomePrintConfig *config)
 {
+	static GHashTable *modules;
 	GnomePrintTransport *transport;
-	guchar *drivername;
-	guchar *modulename;
+	gpointer get_type;
+	GModule *module;
+	gchar *path = NULL;
+	gboolean insert = FALSE;
 
-	g_return_val_if_fail (config != NULL, NULL);
+	if (!modules)
+		modules = g_hash_table_new (g_str_hash, g_str_equal);
+	module = g_hash_table_lookup (modules, module_name);
 
-	drivername = gnome_print_config_get (config, "Settings.Transport.Backend");
-	if (!drivername) {
-		g_warning ("Settings do not specify transport driver");
+	if (!module) {
+		insert = TRUE;
+		path = g_module_build_path (GNOME_PRINT_MODULES_DIR "/transports", module_name);
+		module = g_module_open (path, G_MODULE_BIND_LAZY);
+	}
+
+	if (!module) {
+		insert = TRUE;
+		path = g_module_build_path (GNOME_PRINT_MODULES_DIR, module_name);
+		module = g_module_open (path, G_MODULE_BIND_LAZY);
+	}
+	
+	if (!module) {
+		g_warning ("Could not open %s\n", path);
+		g_free (path);
 		return NULL;
 	}
 
-	transport = NULL;
+	if (insert)
+		g_hash_table_insert (modules, g_strdup (module_name), module);
 
-	modulename = gnome_print_config_get (config, "Settings.Transport.Backend.Module");
-	if (modulename) {
-		static GHashTable *modules = NULL;
-		GModule *module;
-		if (!modules) modules = g_hash_table_new (g_str_hash, g_str_equal);
-		module = g_hash_table_lookup (modules, modulename);
-		if (!module) {
-			gchar *path;
-			path = g_module_build_path (GNOME_PRINT_LIBDIR "/transports", modulename);
-			module = g_module_open (path, G_MODULE_BIND_LAZY);
-			if (module)
-				g_hash_table_insert (modules, g_strdup (modulename), module);
-			else
-				g_warning ("Could not find %s\n", path);
-			g_free (path);
-		}
-		if (module) {
-			gpointer get_type;
-			if (g_module_symbol (module, "gnome_print__transport_get_type", &get_type)) {
-				transport = gnome_print_transport_create (get_type, config);
-			} else {
-				g_warning ("Missing gnome_print__transport_get_type in %s\n", modulename);
-				g_module_close (module);
-			}
-		} else {
-			g_warning ("Cannot open module: %s\n", modulename);
-		}
-		g_free (modulename);
-	} else {
-		g_warning ("Unknown transport driver: %s", modulename);
+	if (!g_module_symbol (module, "gnome_print__transport_get_type", &get_type)) {
+		g_warning ("Missing gnome_print__transport_get_type in %s\n", path);
+		g_module_close (module);
+		g_free (path);
+		return NULL;
 	}
 
-	g_free (drivername);
+	transport = gnome_print_transport_create (get_type, config);
+	if (transport == NULL) {
+		g_warning ("Could not create transport in %s\n", path);
+		g_module_close (module);
+		g_free (path);
+		return NULL;
+	}
+
+	return transport;
+}
+
+GnomePrintTransport *
+gnome_print_transport_new (GnomePrintConfig *config)
+{
+	GnomePrintTransport *transport = NULL;
+	guchar *module_name;
+
+	g_return_val_if_fail (config != NULL, NULL);
+
+	module_name = gnome_print_config_get (config, "Settings.Transport.Backend.Module");
+	if (!module_name) {
+		g_warning ("Could not find \"Settings.Transport.Backend.Module\" using default");
+		module_name = g_strdup ("libgnomeprint-lpr.so");
+	}
+	
+	transport = gnome_print_transport_new_from_module_name (module_name, config);
+
+	g_free (module_name);
 
 	return transport;
 }
